@@ -1,31 +1,31 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="fr_FR">
+<!DOCTYPE TS><TS version="1.1" language="de">
 <context>
     <name>ClientSSL</name>
     <message>
         <location filename="../clientssl.cpp" line="248"/>
         <source>Connected to host</source>
-        <translation>Verbunden mit Host</translation>
+        <translation type="obsolete">Verbunden mit Host</translation>
     </message>
     <message>
         <location filename="../clientssl.cpp" line="264"/>
         <source>Socket error</source>
-        <translation>Socketfehler</translation>
+        <translation type="obsolete">Socketfehler</translation>
     </message>
     <message>
         <location filename="../clientssl.cpp" line="277"/>
         <source>Connection closed</source>
-        <translation>Verbindung getrennt</translation>
+        <translation type="obsolete">Verbindung getrennt</translation>
     </message>
     <message>
         <location filename="../clientssl.cpp" line="143"/>
         <source>Host not found !</source>
-        <translation>Host nicht gefunden !</translation>
+        <translation type="obsolete">Host nicht gefunden !</translation>
     </message>
     <message>
         <location filename="../clientssl.cpp" line="118"/>
         <source>Connection in progress on %1</source>
-        <translation>Verbindung wird aufgebaut bei %1</translation>
+        <translation type="obsolete">Verbindung wird aufgebaut bei %1</translation>
     </message>
 </context>
 <context>
@@ -33,199 +33,342 @@
     <message>
         <location filename="../clientsocket.cpp" line="434"/>
         <source>Properties</source>
-        <translation>Eigenschaften</translation>
+        <translation type="obsolete">Eigenschaften</translation>
     </message>
     <message>
         <location filename="../clientsocket.cpp" line="408"/>
         <source>Send out message to all users</source>
-        <translation>Sende Nachricht an alle Benutzer</translation>
+        <translation type="obsolete">Sende Nachricht an alle Benutzer</translation>
     </message>
     <message>
         <location filename="../clientsocket.cpp" line="418"/>
         <source>Send out message to</source>
-        <translation>Sende Nachricht an</translation>
+        <translation type="obsolete">Sende Nachricht an</translation>
     </message>
     <message>
         <location filename="../clientsocket.cpp" line="428"/>
         <source>Disconnect user</source>
-        <translation>Schliesse Verbindung von User</translation>
+        <translation type="obsolete">Schliesse Verbindung von User</translation>
     </message>
     <message>
         <location filename="../clientsocket.cpp" line="562"/>
         <source>&amp;Yes</source>
-        <translation>&amp;Ja</translation>
+        <translation type="obsolete">&amp;Ja</translation>
     </message>
     <message>
         <location filename="../clientsocket.cpp" line="562"/>
         <source>&amp;No</source>
-        <translation>&amp;Nein</translation>
+        <translation type="obsolete">&amp;Nein</translation>
     </message>
     <message>
         <location filename="../clientsocket.cpp" line="499"/>
         <source>Message to send</source>
-        <translation>Nachricht zum Senden</translation>
+        <translation type="obsolete">Nachricht zum Senden</translation>
     </message>
     <message>
         <location filename="../clientsocket.cpp" line="527"/>
         <source>Message to send to %1:</source>
-        <translation>nachricht zu %1 senden:</translation>
+        <translation type="obsolete">nachricht zu %1 senden:</translation>
     </message>
     <message>
         <location filename="../clientsocket.cpp" line="561"/>
         <source>Do you really want to disconnect user %1 ?</source>
-        <translation>Möchten Sie wirklich die Verbindung von User %1 beenden?</translation>
+        <translation type="obsolete">Möchten Sie wirklich die Verbindung von User %1 beenden?</translation>
     </message>
     <message>
         <location filename="../clientsocket.cpp" line="153"/>
         <source>Host not found !</source>
-        <translation>Host nicht gefunden !</translation>
+        <translation type="obsolete">Host nicht gefunden !</translation>
     </message>
 </context>
 <context>
     <name>LogForm</name>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>Date</source>
         <translation>Datum</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>Machine</source>
         <translation>Maschine</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>User</source>
         <translation>User</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>Service</source>
         <translation>Dienst</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="106"/>
+        <location filename="../log.cpp" line="108"/>
         <source>Open File</source>
         <translation>Öffne Datei</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>Type</source>
         <translation>Belegungstyp</translation>
     </message>
 </context>
 <context>
-    <name>configure</name>
+    <name>MainWindows</name>
     <message>
-        <location filename="../configure.ui" line="13"/>
+        <location filename="../mainwindows.cpp" line="68"/>
+        <source>QtSmbstatus Client</source>
+        <translation type="obsolete">QtSmbstatus Client</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="86"/>
+        <source>Show CIFS/SMB activities</source>
+        <translation>Zeige CIFS/SMB aktivitäten</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="88"/>
         <source>Configure</source>
         <translation>Einrichten</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="251"/>
+        <location filename="../mainwindows.cpp" line="172"/>
+        <source>Minimize</source>
+        <translation>Minimieren</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="93"/>
+        <source>Quit</source>
+        <translation>beenden</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="170"/>
+        <source>Restore</source>
+        <translation>Wiederherstellen</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="245"/>
+        <source>Thanks to:</source>
+        <translation>Dank an:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="259"/>
+        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
+        <translation>This program is licensed to you under the terms of the GNU General Public License version 2</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="291"/>
+        <source>Find text</source>
+        <translation>Text suchen</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="342"/>
+        <source>Text not found.</source>
+        <translation>Text nicht gefunden</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="380"/>
+        <source>User %1 has opened share %2 (%3)</source>
+        <translation>Benutzer %1 hat die Datei(en) %2 (%3) geöffnet</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="381"/>
+        <source>User %1 has opened file %2 (%3)</source>
+        <translation>Benutzer %1 hat dei Datei(en) %2 (%3) geöffnet</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="392"/>
+        <source>CIFS/SMB activities</source>
+        <translation>CIFS/SMB aktivitäten</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="504"/>
+        <source>Message to send</source>
+        <translation>Nachricht zum Senden</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="532"/>
+        <source>Message to send to %1:</source>
+        <translation>nachricht zu %1 senden:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="563"/>
+        <source>Do you really want to disconnect user %1 ?</source>
+        <translation>Möchten Sie wirklich die Verbindung von User %1 beenden?</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="564"/>
+        <source>&amp;Yes</source>
+        <translation>&amp;Ja</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="564"/>
+        <source>&amp;No</source>
+        <translation>&amp;Nein</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="618"/>
+        <source>Properties</source>
+        <translation>Eigenschaften</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="592"/>
+        <source>Send out message to all users</source>
+        <translation>Sende Nachricht an alle Benutzer</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="602"/>
+        <source>Send out message to</source>
+        <translation>Sende Nachricht an</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="612"/>
+        <source>Disconnect user</source>
+        <translation>Schliesse Verbindung von User</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="720"/>
+        <source>Update is available</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="723"/>
+        <source>A new release of %1 is available</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="725"/>
+        <source>You can download it here: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>configure</name>
+    <message>
+        <location filename="../configure.ui" line="19"/>
+        <source>Configure</source>
+        <translation>Einrichten</translation>
+    </message>
+    <message>
+        <location filename="../configure.ui" line="325"/>
         <source>Autoconnect</source>
         <translation>Automatisches Verbinden</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="258"/>
+        <location filename="../configure.ui" line="332"/>
         <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
         <translation>&lt;p align=&quot;right&quot;&gt;Standart Rechner Adresse:&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="235"/>
+        <location filename="../configure.ui" line="309"/>
         <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
         <translation>&lt;p align=&quot;right&quot;&gt;Standart Username:&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="281"/>
+        <location filename="../configure.ui" line="355"/>
         <source>Host Address</source>
         <translation>Rechneradresse</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="178"/>
+        <location filename="../configure.ui" line="62"/>
         <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
         <translation>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="327"/>
+        <location filename="../configure.ui" line="238"/>
         <source>Cancel</source>
         <translation>Abbrechen</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="320"/>
+        <location filename="../configure.ui" line="215"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="271"/>
+        <location filename="../configure.ui" line="345"/>
         <source>Username (default :  username = root)</source>
         <translation>Benutzername</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="108"/>
+        <location filename="../configure.ui" line="190"/>
         <source>Log SMB/CIFS activities</source>
         <translation>Logge SMB/CIFS tätigkeiten</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="98"/>
+        <location filename="../configure.ui" line="180"/>
         <source>Status notification messages</source>
         <translation>Status Benachrichtigung</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="25"/>
+        <location filename="../configure.ui" line="107"/>
         <source>Notifications and log</source>
         <translation>Benachrichten und loggen</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="43"/>
+        <location filename="../configure.ui" line="125"/>
         <source>Limit log:</source>
         <translation>Begrenzter Log:</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="72"/>
+        <location filename="../configure.ui" line="154"/>
         <source>days</source>
         <translation>Tage</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="88"/>
+        <location filename="../configure.ui" line="170"/>
         <source>Iconize QtSmbstatus in system tray</source>
         <translation>Erschaffe QtSmbstatus Icon im System menu</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="147"/>
+        <location filename="../configure.ui" line="31"/>
         <source>Smbstatus</source>
         <translation>Smbstatus</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="191"/>
+        <location filename="../configure.ui" line="75"/>
         <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
         <translation>Intervall zwischen smbstatus anfragen in Sekunden, (intervall &gt;2)</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="204"/>
+        <location filename="../configure.ui" line="88"/>
         <source>Show hidden shares (share$)</source>
-        <translation>Zeige verstecke Anteile (&amp;anteile)</translation>
+        <translation>Zeige verstecke Anteile (share$)</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="207"/>
+        <location filename="../configure.ui" line="91"/>
         <source>Show hidden shares</source>
         <translation>Zeige verstecke Anteile</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="217"/>
+        <location filename="../configure.ui" line="291"/>
         <source>Connection</source>
         <translation>Verbindung</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="248"/>
+        <location filename="../configure.ui" line="322"/>
         <source>Autoconnect on qtsmbstatus startup</source>
         <translation>Automatische Verbindung bei qtsmbstatus start</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="95"/>
+        <location filename="../configure.ui" line="177"/>
         <source>Show activities in &quot;balloon messages&quot;</source>
         <translation>Zeige Aktivität in &quot;Ballon Nachrichten&quot;</translation>
     </message>
+    <message>
+        <location filename="../configure.ui" line="256"/>
+        <source>Misc</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configure.ui" line="265"/>
+        <source>Automatically Check for updates</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configure.ui" line="272"/>
+        <source>A new release is available</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>form_smbstatus</name>
@@ -235,147 +378,147 @@
         <translation>qtsmbstatus</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="174"/>
+        <location filename="../form_smbstatus.ui" line="167"/>
         <source>&amp;Help</source>
         <translation>Hilfe</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="194"/>
+        <location filename="../form_smbstatus.ui" line="188"/>
         <source>&amp;About QtSmbstatus</source>
         <translation>&amp;Über QtSmbstatus</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="211"/>
+        <location filename="../form_smbstatus.ui" line="205"/>
         <source>About &amp;Qt</source>
         <translation>Über &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="41"/>
+        <location filename="../form_smbstatus.ui" line="117"/>
         <source>Connect/Disconnect</source>
         <translation>Verbinden/Trennen</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="65"/>
+        <location filename="../form_smbstatus.ui" line="61"/>
         <source>Host:</source>
         <translation>Host:</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="228"/>
+        <location filename="../form_smbstatus.ui" line="223"/>
         <source>&amp;Configure client</source>
         <translation>&amp;Einstellungen Client</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="161"/>
+        <location filename="../form_smbstatus.ui" line="159"/>
         <source>&amp;Search</source>
         <translation>&amp;Suche</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="239"/>
+        <location filename="../form_smbstatus.ui" line="234"/>
         <source>&amp;Machine</source>
         <translation>&amp;Maschine</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="250"/>
+        <location filename="../form_smbstatus.ui" line="245"/>
         <source>&amp;User</source>
         <translation>&amp;Benutzer</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="261"/>
+        <location filename="../form_smbstatus.ui" line="256"/>
         <source>Share &amp;open</source>
         <translation>Teilen &amp;öffenen</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="272"/>
+        <location filename="../form_smbstatus.ui" line="267"/>
         <source>&amp;Locked file</source>
         <translation>&amp;verschlossene File</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="283"/>
+        <location filename="../form_smbstatus.ui" line="278"/>
         <source>&amp;Next</source>
         <translation>&amp;weiter</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="289"/>
+        <location filename="../form_smbstatus.ui" line="284"/>
         <source>F3</source>
         <translation>F3</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="297"/>
+        <location filename="../form_smbstatus.ui" line="292"/>
         <source>&amp;Find text</source>
         <translation>&amp;Finde Text</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="303"/>
+        <location filename="../form_smbstatus.ui" line="298"/>
         <source>F5</source>
         <translation>F5</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="150"/>
+        <location filename="../form_smbstatus.ui" line="148"/>
         <source>&amp;File</source>
         <translation>&amp;Datei</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="214"/>
+        <location filename="../form_smbstatus.ui" line="208"/>
         <source>About Qt</source>
         <translation>Über Qt</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="231"/>
+        <location filename="../form_smbstatus.ui" line="226"/>
         <source>Configure QtSmbstatus client</source>
         <translation>Einstellung QtSmbstatus Clients</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="242"/>
+        <location filename="../form_smbstatus.ui" line="237"/>
         <source>Search machine</source>
         <translation>Suche Maschine</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="253"/>
+        <location filename="../form_smbstatus.ui" line="248"/>
         <source>Search user</source>
         <translation>Suche User</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="264"/>
+        <location filename="../form_smbstatus.ui" line="259"/>
         <source>Search share open</source>
         <translation>Suche geöffnete Anteile</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="275"/>
+        <location filename="../form_smbstatus.ui" line="270"/>
         <source>Search file open</source>
         <translation>Suche geöffnete Datei</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="286"/>
+        <location filename="../form_smbstatus.ui" line="281"/>
         <source>Next</source>
         <translation>Nächstes</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="300"/>
+        <location filename="../form_smbstatus.ui" line="295"/>
         <source>Find text</source>
         <translation>Text suchen</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="311"/>
+        <location filename="../form_smbstatus.ui" line="307"/>
         <source>&amp;Quit</source>
         <translation>&amp;beenden</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="314"/>
+        <location filename="../form_smbstatus.ui" line="310"/>
         <source>Quit QtSmbstatus</source>
         <translation>Beende QtSmbstatus</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="327"/>
+        <location filename="../form_smbstatus.ui" line="324"/>
         <source>Co&amp;nnect</source>
         <translation>Verbi&amp;nde</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="319"/>
+        <location filename="../form_smbstatus.ui" line="315"/>
         <source>&amp;Show CIFS/SMB activities</source>
         <translation>&amp;Zeige CIFS/SMB aktivitäten</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="197"/>
+        <location filename="../form_smbstatus.ui" line="191"/>
         <source>About QtSmbstatus</source>
         <translation>Über QtSmbstatus</translation>
     </message>
@@ -421,32 +564,32 @@
 <context>
     <name>login_dialog</name>
     <message>
-        <location filename="../login_dialog.ui" line="84"/>
+        <location filename="../login_dialog.ui" line="120"/>
         <source>login</source>
         <translation>Anmelden</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="115"/>
+        <location filename="../login_dialog.ui" line="149"/>
         <source>exit</source>
         <translation>Beenden</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="52"/>
+        <location filename="../login_dialog.ui" line="27"/>
         <source>Username</source>
         <translation>Username</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="132"/>
+        <location filename="../login_dialog.ui" line="49"/>
         <source>root</source>
         <translation>root</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="162"/>
+        <location filename="../login_dialog.ui" line="62"/>
         <source>Password</source>
         <translation>Passwort</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="19"/>
+        <location filename="../login_dialog.ui" line="13"/>
         <source>Connect to qtsmbstatus server</source>
         <translation>Verbinde zum qtsmbstatus Server</translation>
     </message>
@@ -454,109 +597,169 @@
 <context>
     <name>main_windows</name>
     <message>
-        <location filename="../main_windows.cpp" line="416"/>
+        <location filename="../main_windows.cpp" line="533"/>
         <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
-        <translation>This program is licensed to you under the terms of the GNU General Public License version 2</translation>
+        <translation type="obsolete">This program is licensed to you under the terms of the GNU General Public License version 2</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="486"/>
+        <location filename="../main_windows.cpp" line="488"/>
         <source>Search share</source>
-        <translation>Suche Anteile</translation>
+        <translation type="obsolete">Suche Anteile</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="495"/>
+        <location filename="../main_windows.cpp" line="497"/>
         <source>Search locked file</source>
-        <translation>Suche gesperrte Dateien</translation>
+        <translation type="obsolete">Suche gesperrte Dateien</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="651"/>
+        <location filename="../main_windows.cpp" line="627"/>
         <source>Text not found.</source>
-        <translation>Text nicht gefunden</translation>
+        <translation type="obsolete">Text nicht gefunden</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="62"/>
+        <location filename="../main_windows.cpp" line="70"/>
         <source>QtSmbstatus Client</source>
-        <translation>QtSmbstatus Client</translation>
+        <translation type="obsolete">QtSmbstatus Client</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="363"/>
+        <location filename="../main_windows.cpp" line="310"/>
         <source>Connect</source>
         <translation>Verbunden.</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="152"/>
+        <location filename="../main_windows.cpp" line="177"/>
         <source>Minimize</source>
-        <translation>Minimieren</translation>
+        <translation type="obsolete">Minimieren</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="74"/>
+        <location filename="../main_windows.cpp" line="82"/>
         <source>Quit</source>
-        <translation>beenden</translation>
+        <translation type="obsolete">beenden</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="150"/>
+        <location filename="../main_windows.cpp" line="175"/>
         <source>Restore</source>
-        <translation>Wiederherstellen</translation>
+        <translation type="obsolete">Wiederherstellen</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="343"/>
+        <location filename="../main_windows.cpp" line="305"/>
         <source>Disconnect</source>
         <translation>Getrennt</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="737"/>
+        <location filename="../main_windows.cpp" line="665"/>
         <source>User %1 has opened share %2 (%3)</source>
-        <translation>Benutzer %1 hat die Datei(en) %2 (%3) geöffnet</translation>
+        <translation type="obsolete">Benutzer %1 hat die Datei(en) %2 (%3) geöffnet</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="738"/>
+        <location filename="../main_windows.cpp" line="666"/>
         <source>User %1 has opened file %2 (%3)</source>
-        <translation>Benutzer %1 hat dei Datei(en) %2 (%3) geöffnet</translation>
+        <translation type="obsolete">Benutzer %1 hat dei Datei(en) %2 (%3) geöffnet</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="67"/>
+        <location filename="../main_windows.cpp" line="75"/>
         <source>Show CIFS/SMB activities</source>
-        <translation>Zeige CIFS/SMB aktivitäten</translation>
+        <translation type="obsolete">Zeige CIFS/SMB aktivitäten</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="83"/>
+        <location filename="../main_windows.cpp" line="91"/>
         <source>Impossible to know samba version</source>
-        <translation>Unmöglich die Samba Version zukennen</translation>
+        <translation type="obsolete">Unmöglich die Samba Version zukennen</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="394"/>
+        <location filename="../main_windows.cpp" line="356"/>
         <source>Invalid login or password !</source>
         <translation>Falscher Login oder Passwort</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="749"/>
+        <location filename="../main_windows.cpp" line="677"/>
         <source>CIFS/SMB activities</source>
-        <translation>CIFS/SMB aktivitäten</translation>
+        <translation type="obsolete">CIFS/SMB aktivitäten</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="405"/>
+        <location filename="../main_windows.cpp" line="519"/>
         <source>Thanks to:</source>
-        <translation>Dank an:</translation>
+        <translation type="obsolete">Dank an:</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="69"/>
+        <location filename="../main_windows.cpp" line="77"/>
         <source>Configure</source>
-        <translation>Einrichten</translation>
+        <translation type="obsolete">Einrichten</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="456"/>
+        <location filename="../main_windows.cpp" line="576"/>
         <source>Find text</source>
-        <translation>Text suchen</translation>
+        <translation type="obsolete">Text suchen</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="467"/>
+        <location filename="../main_windows.cpp" line="469"/>
         <source>Search machine</source>
-        <translation>Suche Maschine</translation>
+        <translation type="obsolete">Suche Maschine</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="477"/>
+        <location filename="../main_windows.cpp" line="479"/>
         <source>Search user</source>
-        <translation>Suche User</translation>
+        <translation type="obsolete">Suche User</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="198"/>
+        <source>Connection in progress on %1</source>
+        <translation>Verbindung wird aufgebaut bei %1</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="223"/>
+        <source>Connected to host</source>
+        <translation>Verbunden mit Host</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="241"/>
+        <source>Connection closed</source>
+        <translation>Verbindung getrennt</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="965"/>
+        <source>Properties</source>
+        <translation type="obsolete">Eigenschaften</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="939"/>
+        <source>Send out message to all users</source>
+        <translation type="obsolete">Sende Nachricht an alle Benutzer</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="949"/>
+        <source>Send out message to</source>
+        <translation type="obsolete">Sende Nachricht an</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="959"/>
+        <source>Disconnect user</source>
+        <translation type="obsolete">Schliesse Verbindung von User</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="1031"/>
+        <source>Message to send</source>
+        <translation type="obsolete">Nachricht zum Senden</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="1057"/>
+        <source>Message to send to %1:</source>
+        <translation type="obsolete">nachricht zu %1 senden:</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="1089"/>
+        <source>Do you really want to disconnect user %1 ?</source>
+        <translation type="obsolete">Möchten Sie wirklich die Verbindung von User %1 beenden?</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="1090"/>
+        <source>&amp;Yes</source>
+        <translation type="obsolete">&amp;Ja</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="1090"/>
+        <source>&amp;No</source>
+        <translation type="obsolete">&amp;Nein</translation>
     </message>
 </context>
 </TS>
