@@ -1,31 +1,31 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS><TS version="1.1" language="fr_FR">
 <context>
     <name>ClientSSL</name>
     <message>
         <location filename="../clientssl.cpp" line="248"/>
         <source>Connected to host</source>
-        <translation>Connecté au serveur</translation>
+        <translation type="obsolete">Connecté au serveur</translation>
     </message>
     <message>
         <location filename="../clientssl.cpp" line="264"/>
         <source>Socket error</source>
-        <translation>Erreur de Socket</translation>
+        <translation type="obsolete">Erreur de Socket</translation>
     </message>
     <message>
         <location filename="../clientssl.cpp" line="277"/>
         <source>Connection closed</source>
-        <translation>Connexion fermé</translation>
+        <translation type="obsolete">Connexion fermé</translation>
     </message>
     <message>
         <location filename="../clientssl.cpp" line="143"/>
         <source>Host not found !</source>
-        <translation>Hôte introuvable !</translation>
+        <translation type="obsolete">Hôte introuvable !</translation>
     </message>
     <message>
         <location filename="../clientssl.cpp" line="118"/>
         <source>Connection in progress on %1</source>
-        <translation>Connexion en cours sur %1</translation>
+        <translation type="obsolete">Connexion en cours sur %1</translation>
     </message>
 </context>
 <context>
@@ -33,199 +33,342 @@
     <message>
         <location filename="../clientsocket.cpp" line="153"/>
         <source>Host not found !</source>
-        <translation>Hôte introuvable !</translation>
+        <translation type="obsolete">Hôte introuvable !</translation>
     </message>
     <message>
         <location filename="../clientsocket.cpp" line="434"/>
         <source>Properties</source>
-        <translation>Propriétés</translation>
+        <translation type="obsolete">Propriétés</translation>
     </message>
     <message>
         <location filename="../clientsocket.cpp" line="408"/>
         <source>Send out message to all users</source>
-        <translation>Envoyer un message à tous les utilisateurs</translation>
+        <translation type="obsolete">Envoyer un message à tous les utilisateurs</translation>
     </message>
     <message>
         <location filename="../clientsocket.cpp" line="418"/>
         <source>Send out message to</source>
-        <translation>Envoyer un message à</translation>
+        <translation type="obsolete">Envoyer un message à</translation>
     </message>
     <message>
         <location filename="../clientsocket.cpp" line="428"/>
         <source>Disconnect user</source>
-        <translation>Déconnecter l&apos;utilisateur</translation>
+        <translation type="obsolete">Déconnecter l&apos;utilisateur</translation>
     </message>
     <message>
         <location filename="../clientsocket.cpp" line="562"/>
         <source>&amp;Yes</source>
-        <translation>&amp;Oui</translation>
+        <translation type="obsolete">&amp;Oui</translation>
     </message>
     <message>
         <location filename="../clientsocket.cpp" line="562"/>
         <source>&amp;No</source>
-        <translation>&amp;Non</translation>
+        <translation type="obsolete">&amp;Non</translation>
     </message>
     <message>
         <location filename="../clientsocket.cpp" line="499"/>
         <source>Message to send</source>
-        <translation>Message à envoyer</translation>
+        <translation type="obsolete">Message à envoyer</translation>
     </message>
     <message>
         <location filename="../clientsocket.cpp" line="527"/>
         <source>Message to send to %1:</source>
-        <translation>Message à envoyer à %1:</translation>
+        <translation type="obsolete">Message à envoyer à %1:</translation>
     </message>
     <message>
         <location filename="../clientsocket.cpp" line="561"/>
         <source>Do you really want to disconnect user %1 ?</source>
-        <translation>Voulez-vous vraiment déconnecter l&apos;utilisateur %1 ?</translation>
+        <translation type="obsolete">Voulez-vous vraiment déconnecter l&apos;utilisateur %1 ?</translation>
     </message>
 </context>
 <context>
     <name>LogForm</name>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>Date</source>
         <translation>Date</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>Machine</source>
         <translation>Machine</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>User</source>
         <translation>Utilisateur</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>Service</source>
         <translation>Service</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="106"/>
+        <location filename="../log.cpp" line="108"/>
         <source>Open File</source>
         <translation>Fichier ouvert</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>Type</source>
         <translation>Type</translation>
     </message>
 </context>
 <context>
-    <name>configure</name>
+    <name>MainWindows</name>
     <message>
-        <location filename="../configure.ui" line="13"/>
+        <location filename="../mainwindows.cpp" line="68"/>
+        <source>QtSmbstatus Client</source>
+        <translation type="obsolete">QtSmbstatus Client</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="86"/>
+        <source>Show CIFS/SMB activities</source>
+        <translation>Visualiser les activités CIFS/SMB</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="88"/>
         <source>Configure</source>
         <translation>Configure</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="251"/>
+        <location filename="../mainwindows.cpp" line="172"/>
+        <source>Minimize</source>
+        <translation>Réduire</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="93"/>
+        <source>Quit</source>
+        <translation>Quitter</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="170"/>
+        <source>Restore</source>
+        <translation>Restaurer</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="245"/>
+        <source>Thanks to:</source>
+        <translation>Merci à:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="259"/>
+        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
+        <translation>Ce programme est distribué selon les termes de la General Public License version 2 </translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="291"/>
+        <source>Find text</source>
+        <translation>Rechercher un texte</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="342"/>
+        <source>Text not found.</source>
+        <translation>Texte non trouvé.</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="380"/>
+        <source>User %1 has opened share %2 (%3)</source>
+        <translation>Utilisateur %1 a ouvert le partage %2 (%3)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="381"/>
+        <source>User %1 has opened file %2 (%3)</source>
+        <translation>Utilisateur %1 a ouvert le fichier %2 (%3)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="392"/>
+        <source>CIFS/SMB activities</source>
+        <translation>Activités CIFS/SMB</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="504"/>
+        <source>Message to send</source>
+        <translation>Message à envoyer</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="532"/>
+        <source>Message to send to %1:</source>
+        <translation>Message à envoyer à %1:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="563"/>
+        <source>Do you really want to disconnect user %1 ?</source>
+        <translation>Voulez-vous vraiment déconnecter l&apos;utilisateur %1 ?</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="564"/>
+        <source>&amp;Yes</source>
+        <translation>&amp;Oui</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="564"/>
+        <source>&amp;No</source>
+        <translation>&amp;Non</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="618"/>
+        <source>Properties</source>
+        <translation>Propriétés</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="592"/>
+        <source>Send out message to all users</source>
+        <translation>Envoyer un message à tous les utilisateurs</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="602"/>
+        <source>Send out message to</source>
+        <translation>Envoyer un message à</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="612"/>
+        <source>Disconnect user</source>
+        <translation>Déconnecter l&apos;utilisateur</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="720"/>
+        <source>Update is available</source>
+        <translation>Mise à jour disponible</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="723"/>
+        <source>A new release of %1 is available</source>
+        <translation>Une nouvelle version de %1 est disponible</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="725"/>
+        <source>You can download it here: %1</source>
+        <translation>Vous pouvez la télécharger ici: %1</translation>
+    </message>
+</context>
+<context>
+    <name>configure</name>
+    <message>
+        <location filename="../configure.ui" line="19"/>
+        <source>Configure</source>
+        <translation>Configure</translation>
+    </message>
+    <message>
+        <location filename="../configure.ui" line="325"/>
         <source>Autoconnect</source>
         <translation>Autoconnexion</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="258"/>
+        <location filename="../configure.ui" line="332"/>
         <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
         <translation>&lt;p align=&quot;right&quot;&gt;Adresse par défaut du serveur:&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="235"/>
+        <location filename="../configure.ui" line="309"/>
         <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
         <translation>&lt;p align=&quot;right&quot;&gt;Utilisateur par défaut:&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="281"/>
+        <location filename="../configure.ui" line="355"/>
         <source>Host Address</source>
         <translation>Adresse du serveur</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="178"/>
+        <location filename="../configure.ui" line="62"/>
         <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
         <translation>&lt;p align=&quot;right&quot;&gt;Intervalle:&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="327"/>
+        <location filename="../configure.ui" line="238"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="320"/>
+        <location filename="../configure.ui" line="215"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="271"/>
+        <location filename="../configure.ui" line="345"/>
         <source>Username (default :  username = root)</source>
         <translation>Nom de l&apos;utilisateur ( defaut :  username = root)</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="108"/>
+        <location filename="../configure.ui" line="190"/>
         <source>Log SMB/CIFS activities</source>
         <translation>Journal des activités SMB/CIFS</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="98"/>
+        <location filename="../configure.ui" line="180"/>
         <source>Status notification messages</source>
         <translation>Messages de notification d&apos;état</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="25"/>
+        <location filename="../configure.ui" line="107"/>
         <source>Notifications and log</source>
         <translation>Notifications et journal</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="43"/>
+        <location filename="../configure.ui" line="125"/>
         <source>Limit log:</source>
         <translation>Limiter le journal:</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="72"/>
+        <location filename="../configure.ui" line="154"/>
         <source>days</source>
         <translation>jours</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="88"/>
+        <location filename="../configure.ui" line="170"/>
         <source>Iconize QtSmbstatus in system tray</source>
-        <translation>Afficher QtSmbstatus dans la barre à miniatures</translation>
+        <translation>Afficher QtSmbstatus dans la boite à miniatures</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="147"/>
+        <location filename="../configure.ui" line="31"/>
         <source>Smbstatus</source>
         <translation>Smbstatus</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="191"/>
+        <location filename="../configure.ui" line="75"/>
         <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
         <translation>Intervalle, en secondes, entre deux requêtes à smbstatus (intervalle &gt; 2)</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="204"/>
+        <location filename="../configure.ui" line="88"/>
         <source>Show hidden shares (share$)</source>
         <translation>Voir les partages cachés (share$)</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="207"/>
+        <location filename="../configure.ui" line="91"/>
         <source>Show hidden shares</source>
         <translation>Voir les partages cachés</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="217"/>
+        <location filename="../configure.ui" line="291"/>
         <source>Connection</source>
         <translation>Connexion</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="248"/>
+        <location filename="../configure.ui" line="322"/>
         <source>Autoconnect on qtsmbstatus startup</source>
         <translation>Autoconnexion au démarrage de qtsmbstatus</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="95"/>
+        <location filename="../configure.ui" line="177"/>
         <source>Show activities in &quot;balloon messages&quot;</source>
         <translation>Voir les activités dans des info-bulles</translation>
     </message>
+    <message>
+        <location filename="../configure.ui" line="256"/>
+        <source>Misc</source>
+        <translation>Divers</translation>
+    </message>
+    <message>
+        <location filename="../configure.ui" line="265"/>
+        <source>Automatically Check for updates</source>
+        <translation>Rechercher automatiquement des mises à jour</translation>
+    </message>
+    <message>
+        <location filename="../configure.ui" line="272"/>
+        <source>A new release is available</source>
+        <translation>Une nouvelle version est disponible</translation>
+    </message>
 </context>
 <context>
     <name>form_smbstatus</name>
@@ -235,147 +378,147 @@
         <translation>qtsmbstatus</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="174"/>
+        <location filename="../form_smbstatus.ui" line="167"/>
         <source>&amp;Help</source>
         <translation>&amp;Aide</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="194"/>
+        <location filename="../form_smbstatus.ui" line="188"/>
         <source>&amp;About QtSmbstatus</source>
         <translation>&amp;A propos de QtSmbstatus</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="211"/>
+        <location filename="../form_smbstatus.ui" line="205"/>
         <source>About &amp;Qt</source>
         <translation>A propos de &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="41"/>
+        <location filename="../form_smbstatus.ui" line="117"/>
         <source>Connect/Disconnect</source>
         <translation>Connexion/Déconnexion</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="65"/>
+        <location filename="../form_smbstatus.ui" line="61"/>
         <source>Host:</source>
         <translation>Hôte:</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="228"/>
+        <location filename="../form_smbstatus.ui" line="223"/>
         <source>&amp;Configure client</source>
         <translation>&amp;Configure client</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="161"/>
+        <location filename="../form_smbstatus.ui" line="159"/>
         <source>&amp;Search</source>
         <translation>&amp;Rechercher</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="239"/>
+        <location filename="../form_smbstatus.ui" line="234"/>
         <source>&amp;Machine</source>
         <translation>&amp;Machine</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="250"/>
+        <location filename="../form_smbstatus.ui" line="245"/>
         <source>&amp;User</source>
         <translation>&amp;Utilisateur</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="261"/>
+        <location filename="../form_smbstatus.ui" line="256"/>
         <source>Share &amp;open</source>
         <translation>Partage &amp;ouvert</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="272"/>
+        <location filename="../form_smbstatus.ui" line="267"/>
         <source>&amp;Locked file</source>
         <translation>&amp;Fichier ouvert</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="283"/>
+        <location filename="../form_smbstatus.ui" line="278"/>
         <source>&amp;Next</source>
         <translation>&amp;Suivant</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="289"/>
+        <location filename="../form_smbstatus.ui" line="284"/>
         <source>F3</source>
         <translation>F3</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="297"/>
+        <location filename="../form_smbstatus.ui" line="292"/>
         <source>&amp;Find text</source>
         <translation>&amp;Rechercher un texte</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="303"/>
+        <location filename="../form_smbstatus.ui" line="298"/>
         <source>F5</source>
         <translation>F5</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="150"/>
+        <location filename="../form_smbstatus.ui" line="148"/>
         <source>&amp;File</source>
         <translation>&amp;Fichier</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="214"/>
+        <location filename="../form_smbstatus.ui" line="208"/>
         <source>About Qt</source>
         <translation>A propos de Qt</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="231"/>
+        <location filename="../form_smbstatus.ui" line="226"/>
         <source>Configure QtSmbstatus client</source>
         <translation>Configure QtSmbstatus client</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="242"/>
+        <location filename="../form_smbstatus.ui" line="237"/>
         <source>Search machine</source>
         <translation>Rechercher une machine</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="253"/>
+        <location filename="../form_smbstatus.ui" line="248"/>
         <source>Search user</source>
         <translation>Rechercher un utilisateur</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="264"/>
+        <location filename="../form_smbstatus.ui" line="259"/>
         <source>Search share open</source>
         <translation>Rechercher un partage ouvert</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="275"/>
+        <location filename="../form_smbstatus.ui" line="270"/>
         <source>Search file open</source>
         <translation>Rechercher un fichier ouvert</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="286"/>
+        <location filename="../form_smbstatus.ui" line="281"/>
         <source>Next</source>
         <translation>Suivant</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="300"/>
+        <location filename="../form_smbstatus.ui" line="295"/>
         <source>Find text</source>
         <translation>Rechercher un texte</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="311"/>
+        <location filename="../form_smbstatus.ui" line="307"/>
         <source>&amp;Quit</source>
         <translation>&amp;Quitter</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="314"/>
+        <location filename="../form_smbstatus.ui" line="310"/>
         <source>Quit QtSmbstatus</source>
         <translation>Quitter QtSmbstatus</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="327"/>
+        <location filename="../form_smbstatus.ui" line="324"/>
         <source>Co&amp;nnect</source>
         <translation>Co&amp;nnexion</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="319"/>
+        <location filename="../form_smbstatus.ui" line="315"/>
         <source>&amp;Show CIFS/SMB activities</source>
         <translation>&amp;Visualiser les activités CIFS/SMB</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="197"/>
+        <location filename="../form_smbstatus.ui" line="191"/>
         <source>About QtSmbstatus</source>
         <translation>A propos de QtSmbstatus</translation>
     </message>
@@ -421,142 +564,217 @@
 <context>
     <name>login_dialog</name>
     <message>
-        <location filename="../login_dialog.ui" line="84"/>
+        <location filename="../login_dialog.ui" line="120"/>
         <source>login</source>
         <translation>login</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="115"/>
+        <location filename="../login_dialog.ui" line="149"/>
         <source>exit</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="52"/>
+        <location filename="../login_dialog.ui" line="27"/>
         <source>Username</source>
         <translation>Nom</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="132"/>
+        <location filename="../login_dialog.ui" line="49"/>
         <source>root</source>
         <translation>root</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="162"/>
+        <location filename="../login_dialog.ui" line="62"/>
         <source>Password</source>
         <translation>Mot de passe</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="19"/>
+        <location filename="../login_dialog.ui" line="13"/>
         <source>Connect to qtsmbstatus server</source>
-        <translation>Connexion au server</translation>
+        <translation>Connexion au serveur</translation>
     </message>
 </context>
 <context>
     <name>main_windows</name>
     <message>
-        <location filename="../main_windows.cpp" line="416"/>
+        <location filename="../main_windows.cpp" line="533"/>
         <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
-        <translation>Ce programme est distribué selon les termes de la General Public License version 2 </translation>
+        <translation type="obsolete">Ce programme est distribué selon les termes de la General Public License version 2 </translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="456"/>
+        <location filename="../main_windows.cpp" line="576"/>
         <source>Find text</source>
-        <translation>Rechercher un texte</translation>
+        <translation type="obsolete">Rechercher un texte</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="467"/>
+        <location filename="../main_windows.cpp" line="469"/>
         <source>Search machine</source>
-        <translation>Rechercher une machine</translation>
+        <translation type="obsolete">Rechercher une machine</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="477"/>
+        <location filename="../main_windows.cpp" line="479"/>
         <source>Search user</source>
-        <translation>Rechercher un utilisateur</translation>
+        <translation type="obsolete">Rechercher un utilisateur</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="486"/>
+        <location filename="../main_windows.cpp" line="488"/>
         <source>Search share</source>
-        <translation>Rechercher un partage</translation>
+        <translation type="obsolete">Rechercher un partage</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="495"/>
+        <location filename="../main_windows.cpp" line="497"/>
         <source>Search locked file</source>
-        <translation>Rechercher un fichier ouvert</translation>
+        <translation type="obsolete">Rechercher un fichier ouvert</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="651"/>
+        <location filename="../main_windows.cpp" line="627"/>
         <source>Text not found.</source>
-        <translation>Texte non trouvé.</translation>
+        <translation type="obsolete">Texte non trouvé.</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="62"/>
+        <location filename="../main_windows.cpp" line="70"/>
         <source>QtSmbstatus Client</source>
-        <translation>QtSmbstatus Client</translation>
+        <translation type="obsolete">QtSmbstatus Client</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="363"/>
+        <location filename="../main_windows.cpp" line="310"/>
         <source>Connect</source>
         <translation>Connexion</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="69"/>
+        <location filename="../main_windows.cpp" line="77"/>
         <source>Configure</source>
-        <translation>Configure</translation>
+        <translation type="obsolete">Configure</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="152"/>
+        <location filename="../main_windows.cpp" line="177"/>
         <source>Minimize</source>
-        <translation>Réduire</translation>
+        <translation type="obsolete">Réduire</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="74"/>
+        <location filename="../main_windows.cpp" line="82"/>
         <source>Quit</source>
-        <translation>Quitter</translation>
+        <translation type="obsolete">Quitter</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="150"/>
+        <location filename="../main_windows.cpp" line="175"/>
         <source>Restore</source>
-        <translation>Restaurer</translation>
+        <translation type="obsolete">Restaurer</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="343"/>
+        <location filename="../main_windows.cpp" line="305"/>
         <source>Disconnect</source>
         <translation>Déconnexion</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="737"/>
+        <location filename="../main_windows.cpp" line="665"/>
         <source>User %1 has opened share %2 (%3)</source>
-        <translation>Utilisateur %1 a ouvert le partage %2 (%3)</translation>
+        <translation type="obsolete">Utilisateur %1 a ouvert le partage %2 (%3)</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="738"/>
+        <location filename="../main_windows.cpp" line="666"/>
         <source>User %1 has opened file %2 (%3)</source>
-        <translation>Utilisateur %1 a ouvert le fichier %2 (%3)</translation>
+        <translation type="obsolete">Utilisateur %1 a ouvert le fichier %2 (%3)</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="67"/>
+        <location filename="../main_windows.cpp" line="75"/>
         <source>Show CIFS/SMB activities</source>
-        <translation>Visualiser les activités CIFS/SMB</translation>
+        <translation type="obsolete">Visualiser les activités CIFS/SMB</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="83"/>
+        <location filename="../main_windows.cpp" line="91"/>
         <source>Impossible to know samba version</source>
-        <translation>Impossible de connaitre la version de samba</translation>
+        <translation type="obsolete">Impossible de connaitre la version de samba</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="394"/>
+        <location filename="../main_windows.cpp" line="356"/>
         <source>Invalid login or password !</source>
         <translation>Mauvais login ou mauvais mot de passe !</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="749"/>
+        <location filename="../main_windows.cpp" line="677"/>
         <source>CIFS/SMB activities</source>
-        <translation>Activités CIFS/SMB</translation>
+        <translation type="obsolete">Activités CIFS/SMB</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="405"/>
+        <location filename="../main_windows.cpp" line="519"/>
         <source>Thanks to:</source>
-        <translation>Merci à:</translation>
+        <translation type="obsolete">Merci à:</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="198"/>
+        <source>Connection in progress on %1</source>
+        <translation>Connexion en cours sur %1</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="223"/>
+        <source>Connected to host</source>
+        <translation>Connecté au serveur</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="241"/>
+        <source>Connection closed</source>
+        <translation>Connexion fermé</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="965"/>
+        <source>Properties</source>
+        <translation type="obsolete">Propriétés</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="939"/>
+        <source>Send out message to all users</source>
+        <translation type="obsolete">Envoyer un message à tous les utilisateurs</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="949"/>
+        <source>Send out message to</source>
+        <translation type="obsolete">Envoyer un message à</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="959"/>
+        <source>Disconnect user</source>
+        <translation type="obsolete">Déconnecter l&apos;utilisateur</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="1031"/>
+        <source>Message to send</source>
+        <translation type="obsolete">Message à envoyer</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="1057"/>
+        <source>Message to send to %1:</source>
+        <translation type="obsolete">Message à envoyer à %1:</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="1089"/>
+        <source>Do you really want to disconnect user %1 ?</source>
+        <translation type="obsolete">Voulez-vous vraiment déconnecter l&apos;utilisateur %1 ?</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="1090"/>
+        <source>&amp;Yes</source>
+        <translation type="obsolete">&amp;Oui</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="1090"/>
+        <source>&amp;No</source>
+        <translation type="obsolete">&amp;Non</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="1143"/>
+        <source>Update is available</source>
+        <translation type="obsolete">Mise à jour disponible</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="1146"/>
+        <source>A new release of %1 is available</source>
+        <translation type="obsolete">Une nouvelle version de %1 est disponible</translation>
+    </message>
+    <message>
+        <location filename="../main_windows.cpp" line="1148"/>
+        <source>You can download it here: %1</source>
+        <translation type="obsolete">Vous pouvez la télécharger ici: %1</translation>
     </message>
 </context>
 </TS>
