@@ -1,231 +1,288 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS><TS version="1.1" language="ru">
-<context>
-    <name>ClientSSL</name>
-    <message>
-        <location filename="../clientssl.cpp" line="118"/>
-        <source>Connection in progress on %1</source>
-        <translation>Процесс соединения на %1</translation>
-    </message>
-    <message>
-        <location filename="../clientssl.cpp" line="143"/>
-        <source>Host not found !</source>
-        <translation>Хост не найден!</translation>
-    </message>
-    <message>
-        <location filename="../clientssl.cpp" line="248"/>
-        <source>Connected to host</source>
-        <translation>Соединено с хостом</translation>
-    </message>
-    <message>
-        <location filename="../clientssl.cpp" line="264"/>
-        <source>Socket error</source>
-        <translation>Ошибка сокета</translation>
-    </message>
-    <message>
-        <location filename="../clientssl.cpp" line="277"/>
-        <source>Connection closed</source>
-        <translation>Соединение закрыто</translation>
-    </message>
-</context>
-<context>
-    <name>ClientSocket</name>
-    <message>
-        <location filename="../clientsocket.cpp" line="153"/>
-        <source>Host not found !</source>
-        <translation>Хост не найден!</translation>
-    </message>
-    <message>
-        <location filename="../clientsocket.cpp" line="434"/>
-        <source>Properties</source>
-        <translation>Свойства</translation>
-    </message>
-    <message>
-        <location filename="../clientsocket.cpp" line="408"/>
-        <source>Send out message to all users</source>
-        <translation>Сообщение всем пользователям</translation>
-    </message>
-    <message>
-        <location filename="../clientsocket.cpp" line="418"/>
-        <source>Send out message to</source>
-        <translation>Сообщение для</translation>
-    </message>
-    <message>
-        <location filename="../clientsocket.cpp" line="428"/>
-        <source>Disconnect user</source>
-        <translation>Отсоединить пользователя</translation>
-    </message>
-    <message>
-        <location filename="../clientsocket.cpp" line="499"/>
-        <source>Message to send</source>
-        <translation>Сообщение</translation>
-    </message>
-    <message>
-        <location filename="../clientsocket.cpp" line="527"/>
-        <source>Message to send to %1:</source>
-        <translation>Сообщение для %1:</translation>
-    </message>
-    <message>
-        <location filename="../clientsocket.cpp" line="561"/>
-        <source>Do you really want to disconnect user %1 ?</source>
-        <translation>Вы хотите отсоединить пользователя %1 ?</translation>
-    </message>
-    <message>
-        <location filename="../clientsocket.cpp" line="562"/>
-        <source>&amp;Yes</source>
-        <translation>&amp;Да</translation>
-    </message>
-    <message>
-        <location filename="../clientsocket.cpp" line="562"/>
-        <source>&amp;No</source>
-        <translation>&amp;Нет</translation>
-    </message>
-</context>
 <context>
     <name>LogForm</name>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>Date</source>
         <translation>Дата</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>Machine</source>
         <translation>Компьютер</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>User</source>
         <translation>Пользователь</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>Service</source>
         <translation>Сервис</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>Type</source>
         <translation>Тип</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="106"/>
+        <location filename="../log.cpp" line="108"/>
         <source>Open File</source>
         <translation>Открытие файла</translation>
     </message>
 </context>
 <context>
-    <name>configure</name>
+    <name>MainWindows</name>
     <message>
-        <location filename="../configure.ui" line="13"/>
+        <location filename="../mainwindows.cpp" line="86"/>
+        <source>Show CIFS/SMB activities</source>
+        <translation>Показать активность SMB/CIFS</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="88"/>
         <source>Configure</source>
         <translation>Настройка</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="25"/>
+        <location filename="../mainwindows.cpp" line="172"/>
+        <source>Minimize</source>
+        <translation>Минимизировать</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="93"/>
+        <source>Quit</source>
+        <translation>Выход</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="170"/>
+        <source>Restore</source>
+        <translation>Восстановить</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="245"/>
+        <source>Thanks to:</source>
+        <translation>Благодарности:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="259"/>
+        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
+        <translation>Эта программа распространяется под лицензией GNU General Public License версии 2</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="291"/>
+        <source>Find text</source>
+        <translation>Найти текст</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="342"/>
+        <source>Text not found.</source>
+        <translation>Текст не найден.</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="380"/>
+        <source>User %1 has opened share %2 (%3)</source>
+        <translation>Пользователь %1 открыл ресурс %2 (%3)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="381"/>
+        <source>User %1 has opened file %2 (%3)</source>
+        <translation>Пользователь %1 открыл файл %2 (%3)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="392"/>
+        <source>CIFS/SMB activities</source>
+        <translation>Активность SMB/CIFS</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="504"/>
+        <source>Message to send</source>
+        <translation>Сообщение</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="532"/>
+        <source>Message to send to %1:</source>
+        <translation>Сообщение для %1:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="563"/>
+        <source>Do you really want to disconnect user %1 ?</source>
+        <translation>Вы хотите отсоединить пользователя %1 ?</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="564"/>
+        <source>&amp;Yes</source>
+        <translation>&amp;Да</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="564"/>
+        <source>&amp;No</source>
+        <translation>&amp;Нет</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="618"/>
+        <source>Properties</source>
+        <translation>Свойства</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="592"/>
+        <source>Send out message to all users</source>
+        <translation>Сообщение всем пользователям</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="602"/>
+        <source>Send out message to</source>
+        <translation>Сообщение для</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="612"/>
+        <source>Disconnect user</source>
+        <translation>Отсоединить пользователя</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="720"/>
+        <source>Update is available</source>
+        <translation>Доступно обновление</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="723"/>
+        <source>A new release of %1 is available</source>
+        <translation>Доступен новый релиз %1</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="725"/>
+        <source>You can download it here: %1</source>
+        <translation>Вы можете загрузить здесь: %1</translation>
+    </message>
+</context>
+<context>
+    <name>configure</name>
+    <message>
+        <location filename="../configure.ui" line="19"/>
+        <source>Configure</source>
+        <translation>Настройка</translation>
+    </message>
+    <message>
+        <location filename="../configure.ui" line="107"/>
         <source>Notifications and log</source>
         <translation>Уведомления и отчет</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="43"/>
+        <location filename="../configure.ui" line="125"/>
         <source>Limit log:</source>
         <translation>Лимит отчета:</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="72"/>
+        <location filename="../configure.ui" line="154"/>
         <source>days</source>
         <translation>дней</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="88"/>
+        <location filename="../configure.ui" line="170"/>
         <source>Iconize QtSmbstatus in system tray</source>
         <translation>Иконка QtSmbstatus в лотке</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="95"/>
+        <location filename="../configure.ui" line="177"/>
         <source>Show activities in &quot;balloon messages&quot;</source>
         <translation>Активность в &quot;плавающих сообщениях&quot;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="98"/>
+        <location filename="../configure.ui" line="180"/>
         <source>Status notification messages</source>
         <translation>Уведомление статуса</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="108"/>
+        <location filename="../configure.ui" line="190"/>
         <source>Log SMB/CIFS activities</source>
         <translation>Отчет активности SMB/CIFS</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="147"/>
+        <location filename="../configure.ui" line="31"/>
         <source>Smbstatus</source>
         <translation>Smbstatus</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="178"/>
+        <location filename="../configure.ui" line="62"/>
         <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
         <translation>&lt;p align=&quot;right&quot;&gt;Интервал:&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="191"/>
+        <location filename="../configure.ui" line="75"/>
         <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
         <translation>Интервал между запросами smbstatus в секундах (интервал &gt; 2)</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="204"/>
+        <location filename="../configure.ui" line="88"/>
         <source>Show hidden shares (share$)</source>
         <translation>Показать скрытые ресурсы (share$)</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="207"/>
+        <location filename="../configure.ui" line="91"/>
         <source>Show hidden shares</source>
         <translation>Показать скрытые ресурсы</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="217"/>
+        <location filename="../configure.ui" line="291"/>
         <source>Connection</source>
         <translation>Соединение</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="235"/>
+        <location filename="../configure.ui" line="309"/>
         <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
         <translation>&lt;p align=&quot;right&quot;&gt;Пользователь по умолчанию:&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="248"/>
+        <location filename="../configure.ui" line="322"/>
         <source>Autoconnect on qtsmbstatus startup</source>
         <translation>Автоконнект при старте qtsmbstatus</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="251"/>
+        <location filename="../configure.ui" line="325"/>
         <source>Autoconnect</source>
         <translation>Автоконнект</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="258"/>
+        <location filename="../configure.ui" line="332"/>
         <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
         <translation>&lt;p align=&quot;right&quot;&gt;Хост по умолчанию:&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="271"/>
+        <location filename="../configure.ui" line="345"/>
         <source>Username (default :  username = root)</source>
         <translation>Пользователь (по умолчанию :  пользователь = root)</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="281"/>
+        <location filename="../configure.ui" line="355"/>
         <source>Host Address</source>
         <translation>Адрес хоста</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="320"/>
+        <location filename="../configure.ui" line="215"/>
         <source>OK</source>
         <translation>ДА</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="327"/>
+        <location filename="../configure.ui" line="238"/>
         <source>Cancel</source>
         <translation>Отмена</translation>
     </message>
+    <message>
+        <location filename="../configure.ui" line="256"/>
+        <source>Misc</source>
+        <translation>Разное</translation>
+    </message>
+    <message>
+        <location filename="../configure.ui" line="265"/>
+        <source>Automatically Check for updates</source>
+        <translation>Автоматически проверять обновления</translation>
+    </message>
+    <message>
+        <location filename="../configure.ui" line="272"/>
+        <source>A new release is available</source>
+        <translation>Доступен новый релиз</translation>
+    </message>
 </context>
 <context>
     <name>form_smbstatus</name>
@@ -235,147 +292,147 @@
         <translation>qtsmbstatus</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="41"/>
+        <location filename="../form_smbstatus.ui" line="117"/>
         <source>Connect/Disconnect</source>
         <translation>Коннект/Дисконнект</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="65"/>
+        <location filename="../form_smbstatus.ui" line="61"/>
         <source>Host:</source>
         <translation>Хост:</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="150"/>
+        <location filename="../form_smbstatus.ui" line="148"/>
         <source>&amp;File</source>
         <translation>&amp;Файл</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="161"/>
+        <location filename="../form_smbstatus.ui" line="159"/>
         <source>&amp;Search</source>
         <translation>&amp;Поиск</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="174"/>
+        <location filename="../form_smbstatus.ui" line="167"/>
         <source>&amp;Help</source>
         <translation>&amp;Справка</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="194"/>
+        <location filename="../form_smbstatus.ui" line="188"/>
         <source>&amp;About QtSmbstatus</source>
         <translation>&amp;О QtSmbstatus</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="197"/>
+        <location filename="../form_smbstatus.ui" line="191"/>
         <source>About QtSmbstatus</source>
         <translation>О QtSmbstatus</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="211"/>
+        <location filename="../form_smbstatus.ui" line="205"/>
         <source>About &amp;Qt</source>
         <translation>О &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="214"/>
+        <location filename="../form_smbstatus.ui" line="208"/>
         <source>About Qt</source>
         <translation>О Qt</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="228"/>
+        <location filename="../form_smbstatus.ui" line="223"/>
         <source>&amp;Configure client</source>
         <translation>&amp;Конфигурация клиента</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="231"/>
+        <location filename="../form_smbstatus.ui" line="226"/>
         <source>Configure QtSmbstatus client</source>
         <translation>Конфигурация QtSmbstatus клиента</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="239"/>
+        <location filename="../form_smbstatus.ui" line="234"/>
         <source>&amp;Machine</source>
         <translation>&amp;Компьютер</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="242"/>
+        <location filename="../form_smbstatus.ui" line="237"/>
         <source>Search machine</source>
         <translation>Поиск компьютера</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="250"/>
+        <location filename="../form_smbstatus.ui" line="245"/>
         <source>&amp;User</source>
         <translation>&amp;Пользователь</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="253"/>
+        <location filename="../form_smbstatus.ui" line="248"/>
         <source>Search user</source>
         <translation>Поиск пользователя</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="261"/>
+        <location filename="../form_smbstatus.ui" line="256"/>
         <source>Share &amp;open</source>
         <translation>&amp;Открытые ресурсы</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="264"/>
+        <location filename="../form_smbstatus.ui" line="259"/>
         <source>Search share open</source>
         <translation>Поиск открытых ресурсов</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="272"/>
+        <location filename="../form_smbstatus.ui" line="267"/>
         <source>&amp;Locked file</source>
         <translation>&amp;Блокированные файлы</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="275"/>
+        <location filename="../form_smbstatus.ui" line="270"/>
         <source>Search file open</source>
         <translation>Поиск открытых файлов</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="283"/>
+        <location filename="../form_smbstatus.ui" line="278"/>
         <source>&amp;Next</source>
         <translation>&amp;Дальше</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="286"/>
+        <location filename="../form_smbstatus.ui" line="281"/>
         <source>Next</source>
         <translation>Дальше</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="289"/>
+        <location filename="../form_smbstatus.ui" line="284"/>
         <source>F3</source>
         <translation>F3</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="297"/>
+        <location filename="../form_smbstatus.ui" line="292"/>
         <source>&amp;Find text</source>
         <translation>&amp;Найти текст</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="300"/>
+        <location filename="../form_smbstatus.ui" line="295"/>
         <source>Find text</source>
         <translation>Найти текст</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="303"/>
+        <location filename="../form_smbstatus.ui" line="298"/>
         <source>F5</source>
         <translation>F5</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="311"/>
+        <location filename="../form_smbstatus.ui" line="307"/>
         <source>&amp;Quit</source>
         <translation>&amp;Выход</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="314"/>
+        <location filename="../form_smbstatus.ui" line="310"/>
         <source>Quit QtSmbstatus</source>
         <translation>Выйти из QtSmbstatus</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="319"/>
+        <location filename="../form_smbstatus.ui" line="315"/>
         <source>&amp;Show CIFS/SMB activities</source>
         <translation>&amp;Показать активность SMB/CIFS</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="327"/>
+        <location filename="../form_smbstatus.ui" line="324"/>
         <source>Co&amp;nnect</source>
         <translation>Со&amp;единение</translation>
     </message>
@@ -421,32 +478,32 @@
 <context>
     <name>login_dialog</name>
     <message>
-        <location filename="../login_dialog.ui" line="19"/>
+        <location filename="../login_dialog.ui" line="13"/>
         <source>Connect to qtsmbstatus server</source>
         <translation>Соединение с сервером qtsmbstatus</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="52"/>
+        <location filename="../login_dialog.ui" line="27"/>
         <source>Username</source>
         <translation>Пользователь</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="84"/>
+        <location filename="../login_dialog.ui" line="120"/>
         <source>login</source>
         <translation>логин</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="115"/>
+        <location filename="../login_dialog.ui" line="149"/>
         <source>exit</source>
         <translation>выход</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="132"/>
+        <location filename="../login_dialog.ui" line="49"/>
         <source>root</source>
         <translation>root</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="162"/>
+        <location filename="../login_dialog.ui" line="62"/>
         <source>Password</source>
         <translation>Пароль</translation>
     </message>
@@ -454,109 +511,34 @@
 <context>
     <name>main_windows</name>
     <message>
-        <location filename="../main_windows.cpp" line="62"/>
-        <source>QtSmbstatus Client</source>
-        <translation>Клиент QtSmbstatus</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="363"/>
+        <location filename="../main_windows.cpp" line="310"/>
         <source>Connect</source>
         <translation>Соединение</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="67"/>
-        <source>Show CIFS/SMB activities</source>
-        <translation>Показать активность SMB/CIFS</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="69"/>
-        <source>Configure</source>
-        <translation>Настройка</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="152"/>
-        <source>Minimize</source>
-        <translation>Минимизировать</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="74"/>
-        <source>Quit</source>
-        <translation>Выход</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="83"/>
-        <source>Impossible to know samba version</source>
-        <translation>Не могу узнать версию samba</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="150"/>
-        <source>Restore</source>
-        <translation>Восстановить</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="343"/>
+        <location filename="../main_windows.cpp" line="305"/>
         <source>Disconnect</source>
         <translation>Дисконнект</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="394"/>
+        <location filename="../main_windows.cpp" line="356"/>
         <source>Invalid login or password !</source>
         <translation>Неправильный логин или пароль!</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="405"/>
-        <source>Thanks to:</source>
-        <translation>Благодарности:</translation>
+        <location filename="../main_windows.cpp" line="198"/>
+        <source>Connection in progress on %1</source>
+        <translation>Процесс соединения на %1</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="416"/>
-        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
-        <translation>Эта программа распространяется под лицензией GNU General Public License версии 2</translation>
+        <location filename="../main_windows.cpp" line="223"/>
+        <source>Connected to host</source>
+        <translation>Соединено с хостом</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="456"/>
-        <source>Find text</source>
-        <translation>Найти текст</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="467"/>
-        <source>Search machine</source>
-        <translation>Поиск компьютера</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="477"/>
-        <source>Search user</source>
-        <translation>Поиск пользователя</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="486"/>
-        <source>Search share</source>
-        <translation>Поиск ресурсов</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="495"/>
-        <source>Search locked file</source>
-        <translation>Поиск блокированных файлов</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="651"/>
-        <source>Text not found.</source>
-        <translation>Текст не найден.</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="737"/>
-        <source>User %1 has opened share %2 (%3)</source>
-        <translation>Пользователь %1 открыл ресурс %2 (%3)</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="738"/>
-        <source>User %1 has opened file %2 (%3)</source>
-        <translation>Пользователь %1 открыл файл %2 (%3)</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="749"/>
-        <source>CIFS/SMB activities</source>
-        <translation>Активность SMB/CIFS</translation>
+        <location filename="../main_windows.cpp" line="241"/>
+        <source>Connection closed</source>
+        <translation>Соединение закрыто</translation>
     </message>
 </context>
 </TS>
