@@ -1,231 +1,289 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS><TS version="1.1" language="uk">
-<context>
-    <name>ClientSSL</name>
-    <message>
-        <location filename="../clientssl.cpp" line="118"/>
-        <source>Connection in progress on %1</source>
-        <translation>Процес з&apos;єднання з %1</translation>
-    </message>
-    <message>
-        <location filename="../clientssl.cpp" line="143"/>
-        <source>Host not found !</source>
-        <translation>Хост не знайдено!</translation>
-    </message>
-    <message>
-        <location filename="../clientssl.cpp" line="248"/>
-        <source>Connected to host</source>
-        <translation>З&apos;єднано з хостом</translation>
-    </message>
-    <message>
-        <location filename="../clientssl.cpp" line="264"/>
-        <source>Socket error</source>
-        <translation>Помилка сокета</translation>
-    </message>
-    <message>
-        <location filename="../clientssl.cpp" line="277"/>
-        <source>Connection closed</source>
-        <translation>З&apos;єднання закрите</translation>
-    </message>
-</context>
-<context>
-    <name>ClientSocket</name>
-    <message>
-        <location filename="../clientsocket.cpp" line="153"/>
-        <source>Host not found !</source>
-        <translation>Хост не знайдено!</translation>
-    </message>
-    <message>
-        <location filename="../clientsocket.cpp" line="434"/>
-        <source>Properties</source>
-        <translation>Властивості</translation>
-    </message>
-    <message>
-        <location filename="../clientsocket.cpp" line="408"/>
-        <source>Send out message to all users</source>
-        <translation>Повідомлення всім користувачам</translation>
-    </message>
-    <message>
-        <location filename="../clientsocket.cpp" line="418"/>
-        <source>Send out message to</source>
-        <translation>Повідомлення для</translation>
-    </message>
-    <message>
-        <location filename="../clientsocket.cpp" line="428"/>
-        <source>Disconnect user</source>
-        <translation>Від&apos;єднати користувача</translation>
-    </message>
-    <message>
-        <location filename="../clientsocket.cpp" line="499"/>
-        <source>Message to send</source>
-        <translation>Повідомлення</translation>
-    </message>
-    <message>
-        <location filename="../clientsocket.cpp" line="527"/>
-        <source>Message to send to %1:</source>
-        <translation>Повідомлення для %1:</translation>
-    </message>
-    <message>
-        <location filename="../clientsocket.cpp" line="561"/>
-        <source>Do you really want to disconnect user %1 ?</source>
-        <translation>Ви бажаєте від&apos;єднати користувача %1 ?</translation>
-    </message>
-    <message>
-        <location filename="../clientsocket.cpp" line="562"/>
-        <source>&amp;Yes</source>
-        <translation>&amp;Так</translation>
-    </message>
-    <message>
-        <location filename="../clientsocket.cpp" line="562"/>
-        <source>&amp;No</source>
-        <translation>&amp;Ні</translation>
-    </message>
-</context>
+<defaultcodec></defaultcodec>
 <context>
     <name>LogForm</name>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>Date</source>
         <translation>Дата</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>Machine</source>
         <translation>Комп&apos;ютер</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>User</source>
         <translation>Користувач</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>Service</source>
         <translation>Сервіс</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="80"/>
+        <location filename="../log.cpp" line="82"/>
         <source>Type</source>
         <translation>Тип</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="106"/>
+        <location filename="../log.cpp" line="108"/>
         <source>Open File</source>
         <translation>Відкриття файла</translation>
     </message>
 </context>
 <context>
-    <name>configure</name>
+    <name>MainWindows</name>
     <message>
-        <location filename="../configure.ui" line="13"/>
+        <location filename="../mainwindows.cpp" line="86"/>
+        <source>Show CIFS/SMB activities</source>
+        <translation>Показати активність SMB/CIFS</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="88"/>
         <source>Configure</source>
         <translation>Налаштування</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="25"/>
+        <location filename="../mainwindows.cpp" line="172"/>
+        <source>Minimize</source>
+        <translation>Мінімізувати</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="93"/>
+        <source>Quit</source>
+        <translation>Вихід</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="170"/>
+        <source>Restore</source>
+        <translation>Відновити</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="245"/>
+        <source>Thanks to:</source>
+        <translation>Подяки:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="259"/>
+        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
+        <translation>Ця программа розповсюджується під ліцензією GNU General Public License версії 2</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="291"/>
+        <source>Find text</source>
+        <translation>Найти текст</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="342"/>
+        <source>Text not found.</source>
+        <translation>Текст не знайдено.</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="380"/>
+        <source>User %1 has opened share %2 (%3)</source>
+        <translation>Користувач %1 відкрив ресурс %2 (%3)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="381"/>
+        <source>User %1 has opened file %2 (%3)</source>
+        <translation>Користувач %1 відкрив файл %2 (%3)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="392"/>
+        <source>CIFS/SMB activities</source>
+        <translation>Активність SMB/CIFS</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="504"/>
+        <source>Message to send</source>
+        <translation>Повідомлення</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="532"/>
+        <source>Message to send to %1:</source>
+        <translation>Повідомлення для %1:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="563"/>
+        <source>Do you really want to disconnect user %1 ?</source>
+        <translation>Ви бажаєте від&apos;єднати користувача %1 ?</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="564"/>
+        <source>&amp;Yes</source>
+        <translation>&amp;Так</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="564"/>
+        <source>&amp;No</source>
+        <translation>&amp;Ні</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="618"/>
+        <source>Properties</source>
+        <translation>Властивості</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="592"/>
+        <source>Send out message to all users</source>
+        <translation>Повідомлення всім користувачам</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="602"/>
+        <source>Send out message to</source>
+        <translation>Повідомлення для</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="612"/>
+        <source>Disconnect user</source>
+        <translation>Від&apos;єднати користувача</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="720"/>
+        <source>Update is available</source>
+        <translation>Доступне оновлення</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="723"/>
+        <source>A new release of %1 is available</source>
+        <translation>Доступна нова версія %1</translation>
+    </message>
+    <message>
+        <location filename="../mainwindows.cpp" line="725"/>
+        <source>You can download it here: %1</source>
+        <translation>Ви можете завантажити тут: %1</translation>
+    </message>
+</context>
+<context>
+    <name>configure</name>
+    <message>
+        <location filename="../configure.ui" line="19"/>
+        <source>Configure</source>
+        <translation>Налаштування</translation>
+    </message>
+    <message>
+        <location filename="../configure.ui" line="107"/>
         <source>Notifications and log</source>
         <translation>Повідомлення та звіт</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="43"/>
+        <location filename="../configure.ui" line="125"/>
         <source>Limit log:</source>
         <translation>Ліміт звіту:</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="72"/>
+        <location filename="../configure.ui" line="154"/>
         <source>days</source>
         <translation>днів</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="88"/>
+        <location filename="../configure.ui" line="170"/>
         <source>Iconize QtSmbstatus in system tray</source>
         <translation>Іконка QtSmbstatus в треї</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="95"/>
+        <location filename="../configure.ui" line="177"/>
         <source>Show activities in &quot;balloon messages&quot;</source>
         <translation>Активність в &quot;плаваючих повідомленнях&quot;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="98"/>
+        <location filename="../configure.ui" line="180"/>
         <source>Status notification messages</source>
         <translation>Повідомлення статусу</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="108"/>
+        <location filename="../configure.ui" line="190"/>
         <source>Log SMB/CIFS activities</source>
         <translation>Звіт активності SMB/CIFS</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="147"/>
+        <location filename="../configure.ui" line="31"/>
         <source>Smbstatus</source>
         <translation>Smbstatus</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="178"/>
+        <location filename="../configure.ui" line="62"/>
         <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
         <translation>&lt;p align=&quot;right&quot;&gt;Інтервал:&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="191"/>
+        <location filename="../configure.ui" line="75"/>
         <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
         <translation>Інтервал між запитами smbstatus в секундах (інтервал &gt; 2)</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="204"/>
+        <location filename="../configure.ui" line="88"/>
         <source>Show hidden shares (share$)</source>
         <translation>Показати приховані ресурси (share$)</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="207"/>
+        <location filename="../configure.ui" line="91"/>
         <source>Show hidden shares</source>
         <translation>Показати приховані ресурси</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="217"/>
+        <location filename="../configure.ui" line="291"/>
         <source>Connection</source>
         <translation>З&apos;єднання</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="235"/>
+        <location filename="../configure.ui" line="309"/>
         <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
         <translation>&lt;p align=&quot;right&quot;&gt;Користувач за умовчанням:&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="248"/>
+        <location filename="../configure.ui" line="322"/>
         <source>Autoconnect on qtsmbstatus startup</source>
         <translation>Автоз&apos;єднання при старті qtsmbstatus</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="251"/>
+        <location filename="../configure.ui" line="325"/>
         <source>Autoconnect</source>
         <translation>Автоз&apos;єднання</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="258"/>
+        <location filename="../configure.ui" line="332"/>
         <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
         <translation>&lt;p align=&quot;right&quot;&gt;Хост за умовчанням:&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="271"/>
+        <location filename="../configure.ui" line="345"/>
         <source>Username (default :  username = root)</source>
         <translation>Користувач (за умовчанням :  користувач = root)</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="281"/>
+        <location filename="../configure.ui" line="355"/>
         <source>Host Address</source>
         <translation>Адреса хоста</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="320"/>
+        <location filename="../configure.ui" line="215"/>
         <source>OK</source>
         <translation>ТАК</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="327"/>
+        <location filename="../configure.ui" line="238"/>
         <source>Cancel</source>
         <translation>Відміна</translation>
     </message>
+    <message>
+        <location filename="../configure.ui" line="256"/>
+        <source>Misc</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configure.ui" line="265"/>
+        <source>Automatically Check for updates</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configure.ui" line="272"/>
+        <source>A new release is available</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>form_smbstatus</name>
@@ -235,147 +293,147 @@
         <translation>qtsmbstatus</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="41"/>
+        <location filename="../form_smbstatus.ui" line="117"/>
         <source>Connect/Disconnect</source>
         <translation>З&apos;єднання/Від&apos;єднання</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="65"/>
+        <location filename="../form_smbstatus.ui" line="61"/>
         <source>Host:</source>
         <translation>Хост:</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="150"/>
+        <location filename="../form_smbstatus.ui" line="148"/>
         <source>&amp;File</source>
         <translation>&amp;Файл</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="161"/>
+        <location filename="../form_smbstatus.ui" line="159"/>
         <source>&amp;Search</source>
         <translation>&amp;Пошук</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="174"/>
+        <location filename="../form_smbstatus.ui" line="167"/>
         <source>&amp;Help</source>
         <translation>&amp;Довідка</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="194"/>
+        <location filename="../form_smbstatus.ui" line="188"/>
         <source>&amp;About QtSmbstatus</source>
         <translation>&amp;Про QtSmbstatus</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="197"/>
+        <location filename="../form_smbstatus.ui" line="191"/>
         <source>About QtSmbstatus</source>
         <translation>Про QtSmbstatus</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="211"/>
+        <location filename="../form_smbstatus.ui" line="205"/>
         <source>About &amp;Qt</source>
         <translation>Про &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="214"/>
+        <location filename="../form_smbstatus.ui" line="208"/>
         <source>About Qt</source>
         <translation>Про Qt</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="228"/>
+        <location filename="../form_smbstatus.ui" line="223"/>
         <source>&amp;Configure client</source>
         <translation>&amp;Конфігурування клієнта</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="231"/>
+        <location filename="../form_smbstatus.ui" line="226"/>
         <source>Configure QtSmbstatus client</source>
         <translation>Конфігурування QtSmbstatus клієнта</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="239"/>
+        <location filename="../form_smbstatus.ui" line="234"/>
         <source>&amp;Machine</source>
         <translation>&amp;Комп&apos;ютер</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="242"/>
+        <location filename="../form_smbstatus.ui" line="237"/>
         <source>Search machine</source>
         <translation>Пошук комп&apos;ютера</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="250"/>
+        <location filename="../form_smbstatus.ui" line="245"/>
         <source>&amp;User</source>
         <translation>&amp;Користувач</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="253"/>
+        <location filename="../form_smbstatus.ui" line="248"/>
         <source>Search user</source>
         <translation>Пошук користувача</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="261"/>
+        <location filename="../form_smbstatus.ui" line="256"/>
         <source>Share &amp;open</source>
         <translation>&amp;Відкриті ресурси</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="264"/>
+        <location filename="../form_smbstatus.ui" line="259"/>
         <source>Search share open</source>
         <translation>Пошук відкритих ресурсів</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="272"/>
+        <location filename="../form_smbstatus.ui" line="267"/>
         <source>&amp;Locked file</source>
         <translation>&amp;Блоковані файли</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="275"/>
+        <location filename="../form_smbstatus.ui" line="270"/>
         <source>Search file open</source>
         <translation>Пошук відкритих файлів</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="283"/>
+        <location filename="../form_smbstatus.ui" line="278"/>
         <source>&amp;Next</source>
         <translation>&amp;Далі</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="286"/>
+        <location filename="../form_smbstatus.ui" line="281"/>
         <source>Next</source>
         <translation>Далі</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="289"/>
+        <location filename="../form_smbstatus.ui" line="284"/>
         <source>F3</source>
         <translation>F3</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="297"/>
+        <location filename="../form_smbstatus.ui" line="292"/>
         <source>&amp;Find text</source>
         <translation>&amp;Найти текст</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="300"/>
+        <location filename="../form_smbstatus.ui" line="295"/>
         <source>Find text</source>
         <translation>Найти текст</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="303"/>
+        <location filename="../form_smbstatus.ui" line="298"/>
         <source>F5</source>
         <translation>F5</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="311"/>
+        <location filename="../form_smbstatus.ui" line="307"/>
         <source>&amp;Quit</source>
         <translation>&amp;Вихід</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="314"/>
+        <location filename="../form_smbstatus.ui" line="310"/>
         <source>Quit QtSmbstatus</source>
         <translation>Вийти з QtSmbstatus</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="319"/>
+        <location filename="../form_smbstatus.ui" line="315"/>
         <source>&amp;Show CIFS/SMB activities</source>
         <translation>&amp;Показати активність SMB/CIFS</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="327"/>
+        <location filename="../form_smbstatus.ui" line="324"/>
         <source>Co&amp;nnect</source>
         <translation>З&apos;&amp;єднання</translation>
     </message>
@@ -421,32 +479,32 @@
 <context>
     <name>login_dialog</name>
     <message>
-        <location filename="../login_dialog.ui" line="19"/>
+        <location filename="../login_dialog.ui" line="13"/>
         <source>Connect to qtsmbstatus server</source>
         <translation>З&apos;єднання з сервером qtsmbstatus</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="52"/>
+        <location filename="../login_dialog.ui" line="27"/>
         <source>Username</source>
         <translation>Користувач</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="84"/>
+        <location filename="../login_dialog.ui" line="120"/>
         <source>login</source>
         <translation>логін</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="115"/>
+        <location filename="../login_dialog.ui" line="149"/>
         <source>exit</source>
         <translation>вихід</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="132"/>
+        <location filename="../login_dialog.ui" line="49"/>
         <source>root</source>
         <translation>root</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="162"/>
+        <location filename="../login_dialog.ui" line="62"/>
         <source>Password</source>
         <translation>Пароль</translation>
     </message>
@@ -454,109 +512,34 @@
 <context>
     <name>main_windows</name>
     <message>
-        <location filename="../main_windows.cpp" line="62"/>
-        <source>QtSmbstatus Client</source>
-        <translation>Клієнт QtSmbstatus</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="363"/>
+        <location filename="../main_windows.cpp" line="310"/>
         <source>Connect</source>
         <translation>З&apos;єднання</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="67"/>
-        <source>Show CIFS/SMB activities</source>
-        <translation>Показати активність SMB/CIFS</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="69"/>
-        <source>Configure</source>
-        <translation>Налаштування</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="152"/>
-        <source>Minimize</source>
-        <translation>Мінімізувати</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="74"/>
-        <source>Quit</source>
-        <translation>Вихід</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="83"/>
-        <source>Impossible to know samba version</source>
-        <translation>Не можу взнати версію samba</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="150"/>
-        <source>Restore</source>
-        <translation>Відновити</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="343"/>
+        <location filename="../main_windows.cpp" line="305"/>
         <source>Disconnect</source>
         <translation>Від&apos;єднання</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="394"/>
+        <location filename="../main_windows.cpp" line="356"/>
         <source>Invalid login or password !</source>
         <translation>Неправильний логін чи пароль!</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="405"/>
-        <source>Thanks to:</source>
-        <translation>Подяки:</translation>
+        <location filename="../main_windows.cpp" line="198"/>
+        <source>Connection in progress on %1</source>
+        <translation>Процес з&apos;єднання з %1</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="416"/>
-        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
-        <translation>Ця программа розповсюджується під ліцензією GNU General Public License версії 2</translation>
+        <location filename="../main_windows.cpp" line="223"/>
+        <source>Connected to host</source>
+        <translation>З&apos;єднано з хостом</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="456"/>
-        <source>Find text</source>
-        <translation>Знайти текст</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="467"/>
-        <source>Search machine</source>
-        <translation>Пошук комп&apos;ютера</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="477"/>
-        <source>Search user</source>
-        <translation>Пошук користувача</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="486"/>
-        <source>Search share</source>
-        <translation>Пошук ресурсів</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="495"/>
-        <source>Search locked file</source>
-        <translation>Пошук блокованих файлів</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="651"/>
-        <source>Text not found.</source>
-        <translation>Текст не знайдено.</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="737"/>
-        <source>User %1 has opened share %2 (%3)</source>
-        <translation>Користувач %1 відкрив ресурс %2 (%3)</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="738"/>
-        <source>User %1 has opened file %2 (%3)</source>
-        <translation>Користувач %1 відкрив файл %2 (%3)</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="749"/>
-        <source>CIFS/SMB activities</source>
-        <translation>Активність SMB/CIFS</translation>
+        <location filename="../main_windows.cpp" line="241"/>
+        <source>Connection closed</source>
+        <translation>З&apos;єднання закрите</translation>
     </message>
 </context>
 </TS>
